DROP TABLE IF EXISTS facilities;
CREATE TABLE facilities(
      id INTEGER,
      year INTEGER, 
      name TEXT,
      administrative_number TEXT,
      wgs84_x REAL, 
      wgs84_y REAL, 
      street TEXT,
      house_number TEXT,
      postcode TEXT,
      city TEXT,
      federal_state TEXT,
      river_basin TEXT,
      parent_company TEXT,
      owner TEXT,
      operator TEXT,
      production_volume TEXT,
      number_of_production_lines INTEGER,
      operating_hours INTEGER,
      prtr_info TEXT, 
      nace_code INTEGER,
      nace_text TEXT, 
      predecessor_id INTEGER 
);
