DROP TABLE IF EXISTS releases;
CREATE TABLE releases ( 
    id INTEGER,
    facility_id INTEGER, 
    year INTEGER, 
    compartment TEXT,
    annual_load REAL,
    annual_load_accident REAL,
    annual_load_non_biogenic REAL,
    substance_name TEXT,
    substance_group TEXT, 
    substance_casnumber TEXT, 
    substance_threshold REAL,
    determination_method TEXT,
    determination_procedure TEXT
);
