DROP TABLE IF EXISTS abwasserverbringungen ;
CREATE TABLE abwasserverbringungen (
    id INTEGER,
    betriebe_id INTEGER,
    jahr INTEGER,
    jahresfracht REAL,
    stoff_name TEXT,
    stoff_gruppe TEXT,
    stoff_casnummer TEXT,
    stoff_schwellenwert REAL,
    bestimmungsmethode TEXT,
    bestimmungsverfahren TEXT
);
