DROP TABLE IF EXISTS revisions;
CREATE TABLE revisions (
	revision INTEGER,
	db_release CHARACTER VARYING(32),
	generator_version CHARACTER VARYING(32),
	release_date INTEGER,
	release_time INTEGER,
	comment CHARACTER VARYING(2048)
);