DROP TABLE IF EXISTS taetigkeiten;
CREATE TABLE taetigkeiten (
	id INTEGER,
	betriebe_id INTEGER,
	jahr INTEGER,
	haupttaetigkeit BOOL,
	prtr_schluessel TEXT,
	prtr_beschreibung TEXT,
	ivu_schluessel TEXT,
	ivu_beschreibung TEXT,
	branchengruppe TEXT
);
