DROP TABLE IF EXISTS betriebe;
CREATE TABLE betriebe (
      id INTEGER,
      jahr INTEGER,
      name TEXT,
      kennnummer TEXT,
      wgs84_x REAL,
      wgs84_y REAL,
      strasse TEXT,
      hausnummer TEXT,
      postleitzahl TEXT,
      ort TEXT,
      bundesland TEXT,
      flusseinzugsgebiet TEXT,
      muttergesellschaft TEXT,
      eigentuemer TEXT,
      betreiber TEXT,
      produktionsvolumen TEXT,
      anlagenanzahl INTEGER,
      betriebsstunden INTEGER,
      prtrinfo TEXT,
      nace_code INTEGER,
      nace_text TEXT,
      vorgaenger_id INTEGER
);
