DROP TABLE IF EXISTS waste_transfers;
CREATE TABLE waste_transfers ( 
    id INTEGER,
    facility_id INTEGER, 
    year INTEGER,
    quantity REAL,
    hazardous BOOL, 
    foreign_country BOOL,
    disposition TEXT,
    determination_method TEXT, 
    determination_procedure TEXT, 
    waste_handler_party TEXT,
    site_address TEXT
);
