#!/bin/bash
# -*- coding: utf-8 -*-
#
# Please note the README in the parent folder!
# Bitte beachten Sie die README Datei im Überordner.

mkdir -p ../data
mkdir -p ../config
cp -n ./db.yml ../config/db_source.yml
cp -n ./db.yml ../config/db_target_de.yml
cp -n ./db.yml ../config/db_target_en.yml
cp -n ./db.yml ../config/db_target_inspire.yml
