# -*- coding: utf-8 -*-
class Betrieb < Entry
#  attr_accessor :taet, :freis, :vabw, :vabf
#  @initialized = false
  def write_out
    $db_target.execute("INSERT INTO betriebe (
      id,
      jahr,
      name,
      kennnummer,
      wgs84_x,
      wgs84_y,
      strasse,
      hausnummer,
      postleitzahl,
      ort,
      bundesland,
      flusseinzugsgebiet,
      muttergesellschaft,
      eigentuemer,
      betreiber,
      produktionsvolumen,
      anlagenanzahl,
      betriebsstunden,
      prtrinfo,
      nace_code,
      nace_text,
      vorgaenger_id
      ) VALUES (
      #{sqlize('id')},
      #{sqlize('jahr')},
      #{sqlize('name')},
      #{sqlize('kennnr')},
      #{sqlize('geo_x')},
      #{sqlize('geo_y')},
      #{sqlize('strasse')},
      #{sqlize('hausnummer')},
      #{sqlize('postleitzahl')},
      #{sqlize('ort')},
      #{sqlize('buland')},
      #{sqlize('flusseinzugsgebiet')},
      #{sqlize('muttergesellschaft')},
      #{sqlize('eigname')},
      #{sqlize('betname')},
      #{sqlize('prodvol')},
      #{sqlize('anlzahl')},
      #{sqlize('betriebh')},
      #{sqlize('prtrinfo')},
      #{sqlize('nace_key')},
      #{sqlize('nace_text')},
      #{sqlize('p_betrieb_vorgaenger_id')}
      )")
    @geheimk.each do |gk|
      $db_target.execute("INSERT INTO betriebe_gg (betriebe_id, grund) VALUES (#{@data['id']},'#{gk[1]}')")
    end

  end

end
