DROP TABLE IF EXISTS wastewater_transfers;
CREATE TABLE wastewater_transfers (
    id INTEGER,
    facility_id INTEGER,
    year INTEGER,
    annual_load REAL,
    substance_name TEXT, 
    substance_group TEXT,
    substance_casnumber TEXT,
    substance_threshold REAL,
    determination_method TEXT,
    determination_procedure TEXT
);
