DROP TABLE IF EXISTS abfallverbringungen;
CREATE TABLE abfallverbringungen (
    id INTEGER,
    betriebe_id INTEGER,
    jahr INTEGER,
    menge REAL,
    gefaehrlich BOOL,
    ins_ausland BOOL,
    disposition TEXT,
    bestimmungsmethode TEXT,
    bestimmungsverfahren TEXT,
    entsorger TEXT,
    entsorgungsort TEXT
);

