DROP TABLE IF EXISTS revisionen;
CREATE TABLE revisionen (
    revision INTEGER,
    db_release CHARACTER VARYING(32),
    generator_version CHARACTER VARYING(32),
    release_date INTEGER,
    release_time INTEGER,
    bemerkung CHARACTER VARYING(2048)
);
