# -*- coding: utf-8 -*-
class Freis < Entry
#  @@initialized = false
  def initialize(row, gk_table)
    super(row,gk_table)
    @data['schwellenwert'] = case @data['kompartiment']
                               when 'Luft' then @data['schwellenwert_luft']
                               when 'Wasser' then @data['schwellenwert_wasser']
                               when 'Boden' then @data['schwellenwert_boden']
    end
  end

  def write_out()
    $db_target.execute("INSERT INTO freisetzungen (
        id,
        betriebe_id,
        jahr,
        kompartiment,
        jahresfracht,
        jahresfracht_versehentlich,
        jahresfracht_nichtbiogen,
        stoff_name,
        stoff_gruppe,
        stoff_casnummer,
        stoff_schwellenwert,
        bestimmungsmethode,
        bestimmungsverfahren
      ) VALUES (
      #{sqlize('id')},
      #{sqlize('p_betrieb_id')},
      #{sqlize('jahr')},
      #{sqlize('kompartiment')},
      #{sqlize('jfracht')},
      #{sqlize('vfracht')},
      #{sqlize('nbiofracht')},
      #{sqlize('stoffname')},
      #{sqlize('stoffgruppe')},
      #{sqlize('cas_nr')},
      #{sqlize('schwellenwert')},
      #{sqlize('bmeth')},
      #{sqlize('bverf')}
      )")
    @geheimk.each do |gk|
      $db_target.execute("INSERT INTO freisetzungen_gg (freisetzungen_id, grund) VALUES (#{@data['id']},'#{gk[1]}')")
    end

  end


end
