DROP TABLE IF EXISTS activities;
CREATE TABLE activities (
	id INTEGER,
	facility_id INTEGER, 
	year INTEGER, 
	main_activity BOOL, 
	prtr_key TEXT,
	prtr_description TEXT,
	ippc_key TEXT,
	ippc_description TEXT,
	business_sector TEXT
);
