DROP TABLE IF EXISTS inspire;
CREATE TABLE inspire (      
      jahr INTEGER,
      bundesland INTEGER,
      kennnummer TEXT,
      betriebsname TEXT,
      rw_wgs84 REAL,
      hw_wgs84 REAL,
      rw_etrs89_utm32 REAL,
      hw_etrs89_utm32 REAL,
      strasse TEXT,
      nr TEXT,
      plz TEXT,
      ort TEXT,
      gemeindeschluessel TEXT,
      gemeindename TEXT,
      process INTEGER
);
